==> qmmp-0.6.4.tar.bz2: qmmp-0.6.4/src/plugins/Input/wildmidi/translations/wildmidi_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="43"/>
        <source>WildMidi Plugin</source>
        <translation>WildMidi įskiepis</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="45"/>
        <source>Midi Files</source>
        <translation>Midi bylos</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="100"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>Apie WildMidi Audio įskiepį</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="101"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>Qmmp WildMidi Audio įskiepis</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="102"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>Šis įskiepis naudoja WildMidi biblioteką midi bylų grojimui</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="103"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation>WildMidi įskiepio nustatymai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation>Instrumentų nustatymai:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="53"/>
        <source>Sample rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="60"/>
        <source>Enhanced resampling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="67"/>
        <source>Reverberation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
</context>
</TS>

==> qmmp_0.8.2.orig.tar.bz2: qmmp-0.8.2/src/plugins/Input/wildmidi/translations/wildmidi_plugin_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>DecoderWildMidiFactory</name>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="48"/>
        <source>WildMidi Plugin</source>
        <translation>WildMidi įskiepis</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="50"/>
        <source>Midi Files</source>
        <translation>Midi bylos</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="104"/>
        <source>About WildMidi Audio Plugin</source>
        <translation>Apie WildMidi Audio įskiepį</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="105"/>
        <source>Qmmp WildMidi Audio Plugin</source>
        <translation>Qmmp WildMidi Audio įskiepis</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="106"/>
        <source>This plugin uses WildMidi library to play midi files</source>
        <translation>Šis įskiepis naudoja WildMidi biblioteką midi bylų grojimui</translation>
    </message>
    <message>
        <location filename="../decoderwildmidifactory.cpp" line="107"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>WildMidi Plugin Settings</source>
        <translation>WildMidi įskiepio nustatymai</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Instrument configuration: </source>
        <translation>Instrumentų nustatymai:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="43"/>
        <source>Sample rate:</source>
        <translation>Dažnis:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="50"/>
        <source>Enhanced resampling</source>
        <translation type="unfinished">Patobulintas formatavimas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Reverberation</source>
        <translation type="unfinished">Atgarsis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
</context>
</TS>
